/*
 *  GuiLoader/C++ examples
 *  Copyright (c) 2006 Maxim Udushlivy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifdef _WIN32
	#include <gdk/gdkwin32.h>
#endif

#include <glib/gi18n.h>
#include <guiloader-c++.h> 

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

namespace GuiExample {

class Application : public sigc::trackable {

public:
	Application() {
		loader= Gui::Loader::create();

		GUIXML_DECL
			#include "hello.gui.h"
		GUIXML_LOAD_CPP(loader)

		loader->bind_object("window1", &window);
	}
	
	Gtk::Window * getWindow() { return window; }

private:
	Gui::PLoader loader;
	Gtk::Window * window;

};

int Main(int argc, char ** argv) {
	Gtk::Main gtkmain(&argc, &argv);
	Gui::Enter enter;

	#if ENABLE_NLS
		bindtextdomain(PACKAGE, LOCALEDIR);
		bind_textdomain_codeset(PACKAGE, "UTF-8");
		textdomain(PACKAGE);
	#endif

	Application application;
	Gtk::Main::run(*application.getWindow());
	return 0;
}

}

#ifdef _WIN32
	int WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
		{ return GuiExample::Main(__argc, __argv); }
#else
	int main(int argc, char ** argv) 
		{ return GuiExample::Main(argc, argv); }
#endif
