/*
 *  GuiLoader/C++, a C++ binding to GuiLoader
 *  Copyright (c) 2006 Maxim Udushlivy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef GUILOADER_CPP_GUILOADER_CPP_IMPL_H
#define GUILOADER_CPP_GUILOADER_CPP_IMPL_H

#define GUILOADER_CPP_LIBRARY

#ifdef GUILOADER_CPP_SANDBOX
	#define G_DISABLE_DEPRECATED
	#define GDK_DISABLE_DEPRECATED
	#define GDK_PIXBUF_DISABLE_DEPRECATED
	#define PANGO_DISABLE_DEPRECATED
	#define GTK_DISABLE_DEPRECATED
	#define GTKMM_DISABLE_DEPRECATED
#endif

#include <assert.h>
#include <guiloader.h>
#include <map>
#include <sstream>

#include "guiloader-c++.h"

#ifdef G_LOG_DOMAIN
	#undef G_LOG_DOMAIN
#endif
#define G_LOG_DOMAIN "GuiLoader/C++"

#define Check(expr) if(!(expr)) CheckFailed(#expr, __FILE__, __LINE__); else

namespace Gui {

void CheckFailed(const char * expr, const char * file, unsigned line);
void FatalError(const std::string & message);
Glib::Object * Wrap(GObject * gobj);

template <class T, class U> class TSignalConnector : public TSignal<typename T::SlotType> {

public:
	typedef T (U::*get_signal_func)();
	typedef typename T::SlotType Slot;

	TSignalConnector(get_signal_func func) {
		get_signal= func;
	}

	bool connect(Glib::Object * obj, const Slot & slot, bool after) {
		U * object= dynamic_cast<U *>(obj);
		if(object)
			(object->*get_signal)().connect(slot, after);
		return object;
	}

private:
	get_signal_func get_signal;

};

class LoaderInit {

public:
	static LoaderInit * get();

	static void enter();
	static void leave();

	Signal * findSignal(const std::string & name, GType type);

protected:
	static LoaderInit * & ptr();

	LoaderInit();
	~LoaderInit();

	void addingSignals(GType sigclass) { this->sigclass= sigclass; }

	template <class T, class U> void addSignal(
		const std::string & name,
		T (U::*get_signal)()
	) {
		signals.insert(std::make_pair(name, std::make_pair(sigclass, new TSignalConnector<T, U>(get_signal))));
	}

private:
	int refcounter;
	GType sigclass;
	
	typedef std::multimap<std::string, std::pair<GType, Signal *> > Signals;
	Signals signals;

};

}

#endif
